BD-Func [3] will compare the expression patterns for the up-regulated genes to the down-regulated genes.
data(bdfunc.enrichment.human)[2] Liberzon A, Subramanian A, Pinchback R, Thorvaldsdottir H, Tamayo P, and Mesirov JP.(2011). Molecular signatures database (MSigDB) 3.0. Bioinformatics, 27:1739-1740.
[3] Warden CD, Kanaya N, Chen S, and Yuan Y-C. (2013). BD-Func: A Streamlined Algorithm for Predicting Activation and Inhibition of Pathways. peerJ, 1:e159